StructInspect.Overrides (struct_inspect v0.1.4)
View SourceProvides a mechanism to globally override the Inspect implementation for structs.
This module allows you to configure StructInspect to take over the inspection of any
struct, even for libraries or dependencies where you cannot add use StructInspect
directly.
The overrides are configured in your config/config.exs file.
Summary
Functions
Generates Inspect implementations for the modules configured in the application environment.
This macro reads the :struct_inspect, :overrides configuration and for each module,
it generates a defimpl Inspect that uses StructInspect.inspect/3 for inspection.